[Libreoffice-commits] core.git: Branch 'libreoffice-3-6' - sw/source

Miklos Vajna vmiklos at suse.cz
Thu Mar 21 22:47:54 PDT 2013


 sw/source/core/doc/docfld.cxx |   14 ++++++++++----
 1 file changed, 10 insertions(+), 4 deletions(-)

New commits:
commit 75e7e130448182c15697c8dd0b8d50324db4f79f
Author: Miklos Vajna <vmiklos at suse.cz>
Date:   Wed Mar 20 13:19:32 2013 +0100

    fdo#55814 SwDoc::UpdateExpFlds: hiding the last section may be safe
    
    In case we know there is a non-section paragraph at the end of the
    document.  Intentionally not adding a unit test as David Ostrovsky is
    working on one already.
    
    (cherry picked from commit 62344016de056965a58ea2016d912a68eac0d6b0)
    
    Conflicts:
    	sw/source/core/doc/docfld.cxx
    
    Change-Id: Ia6026846981b5af014246a8a604c5f762d34c891
    Reviewed-on: https://gerrit.libreoffice.org/2901
    Reviewed-by: David Ostrovsky <David.Ostrovsky at gmx.de>
    Tested-by: David Ostrovsky <David.Ostrovsky at gmx.de>
    Reviewed-by: Fridrich Strba <fridrich at documentfoundation.org>
    Tested-by: Fridrich Strba <fridrich at documentfoundation.org>

diff --git a/sw/source/core/doc/docfld.cxx b/sw/source/core/doc/docfld.cxx
index a2a58fc..69e13dc 100644
--- a/sw/source/core/doc/docfld.cxx
+++ b/sw/source/core/doc/docfld.cxx
@@ -1325,10 +1325,16 @@ void SwDoc::UpdateExpFlds( SwTxtFld* pUpdtFld, bool bUpdRefFlds )
                     // This section will be hidden, but it wasn't before
                     if (nShownSections == 1)
                     {
-                        // This would be the last section, so set its condition to false, and avoid hiding it.
-                        rtl::OUString aCond(RTL_CONSTASCII_USTRINGPARAM("0"));
-                        pSect->SetCondition(aCond);
-                        bHide = false;
+                        // Is the last node part of a section?
+                        SwPaM aPam(GetNodes());
+                        aPam.Move(fnMoveForward, fnGoDoc);
+                        if (aPam.Start()->nNode.GetNode().StartOfSectionNode()->IsSectionNode())
+                        {
+                            // This would be the last section, so set its condition to false, and avoid hiding it.
+                            rtl::OUString aCond(RTL_CONSTASCII_USTRINGPARAM("0"));
+                            pSect->SetCondition(aCond);
+                            bHide = false;
+                        }
                     }
                     nShownSections--;
                 }


More information about the Libreoffice-commits mailing list